@@ -66,13 +66,10 @@ STATUS_CODES = (
     (505, 'HTTP Version Not Supported'),
 )
 
-class ResponseTypes(OrderedDict):
-    def __init__(self, choices):
-        super(ResponseTypes, self).__init__(choices)
-        for code, label in choices:
-            setattr(self, re.sub(r'\W', '_', label.upper()), code)
-
-STATUS = ResponseTypes(STATUS_CODES)
+STATUS = OrderedDict(STATUS_CODES)
+# Set constant-like properties for reverse lookup
+for code, label in STATUS_CODES:
+    setattr(STATUS, re.sub(r'\W', '_', label.upper()), code)
 
 class BaseHttpResponse(HttpResponse, Exception):
     '''
